{#
    ubuntu/sidebar.html
    ~~~~~~~~~~~~~~~~~

    Ubuntu layout template for Sphinx themes.

    :copyright: Copyright 2007-2010 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}

  <div id="sidebar" class="grid_3 omega">
    <div class="container-tweet">

      {%- if logo %}
        <p class="logo"><a href="{{ pathto(master_doc) }}">
          <img class="logo" src="{{ pathto('_static/' + logo, 1) }}" alt="Logo"/>
        </a></p>
      {%- endif %}

      {%- if display_toc %}
        <h3>{{ _('Table Of Contents') }}</h3>
        <div class="toc">
          {{ toc }}
        </div>
      {%- endif %}

      <div class="browse-guide">
        <h3>{{_('Browse The Guide')}}:</h3>
        <ul>
          <li class="prev{%- if not prev %} disabled{%- endif %}">
            {%- if prev %}
            <a href="{{ prev.link|e }}"
                      title="{{ _('Previous topic') }}: {{ prev.title }}">Go Previous</a>
            {%- endif %}
          </li>
          
          <li class="center">
            <a title="{{ _('Back to Index') }}" href="{{ pathto(master_doc) }}">Index Guide</a>
          </li>
        
          <li class="next{%- if not next %} disabled{%- endif %}">
            {%- if next %}
            <a href="{{ next.link|e }}"
                      title="{{ _('Next topic') }}: {{ next.title }}">Go Next</a>
            {%- endif %}
          </li>
        </ul>
        {%- if show_source and has_source and sourcename %}
        <span>{{ _('This Page') }}:</span> <a href="{{ pathto('_sources/' + sourcename, true)|e }}"
               rel="nofollow">{{ _('Show Source') }}</a>
        {%- endif %}
      </div>
     </div>
     <div id="back_top"><a href="#top">{{ _('Back to Top') }}</a></div>
    </div>
